==> replicated-config-render-1.0.1.tgz: package/components/Configure.jsx <==
var _ = require('lodash');
var React = require('react');

var ConfigGroups = require('./ConfigGroups.jsx');

var Configure = React.createClass({
  getInitialState: function() {
    return {
      groups: this.props.groups
    };
  },

  handleGroupsChange: function(groupName, itemName, value, data) {
    var groups = _.map(this.state.groups, function(group) {
      if (group.name === groupName) {
        group.items = _.map(group.items, function(item) {
          if (!(item.type in ['select_many', 'label', 'heading']) &&
              item.name === itemName) {
            item.value = value;
            if (item.type === 'file') {
              item.data = data;
            }
          } else {
            if (item.type !== 'select_one') {
              item.items = _.map(item.items, function(childItem) {
                if (childItem.name === itemName) {
                  childItem.value = value;
                  if (childItem.type === 'file') {
                    childItem.data = data;
                  }
                }
                return childItem;
              });
            }
          }
          return item;
        });
      }
      return group;
    });

    this.setState({groups: groups});

    // TODO: maybe this should only be on submit
    this.triggerChange(groups);
  },

  triggerChange: function(groups) {
    this.props.handleChange && this.props.handleChange(this.getData(groups));
  },

  getData: function(groups) {
    if (!groups) {
      groups = this.state.groups;
    }

    var getItemData = function(item) {
      var data = {
        'name': item.name,
        'value': item.value
      };
      if (item.type === 'file') {
        data.data = item.data;
      }
      return data;
    };

    var data = [];
    _.each(groups, function(group) {
      _.each(group.items, function(item) {
        if (item.type !== 'select_many') {
          data.push(getItemData(item));
        }
        if (item.type !== 'select_one') {
          _.each(item.items, function(childItem) {
            data.push(getItemData(childItem));
          });
        }
      });
    });

    return data;
  },

  render: function() {
    return (
      <ConfigGroups
        groups={this.state.groups}
        handleChange={this.handleGroupsChange} />
    );
  }
});

module.exports = Configure;

==> replicated-config-render-1.0.5.tgz: package/components/Configure.jsx <==
var _ = require('lodash');
var React = require('react');

var ConfigGroups = require('./ConfigGroups.jsx');

var Configure = React.createClass({
  getInitialState: function() {
    return {
      groups: this.props.groups
    };
  },

  componentWillReceiveProps: function(nextProps) {
    this.setState({groups: nextProps.groups});
  },

  handleGroupsChange: function(groupName, itemName, value, data) {
    var groups = _.map(this.state.groups, function(group) {
      if (group.name === groupName) {
        group.items = _.map(group.items, function(item) {
          if (!(item.type in ['select_many', 'label', 'heading']) &&
              item.name === itemName) {
            item.value = value;
            if (item.type === 'file') {
              item.data = data;
            }
          } else {
            if (item.type !== 'select_one') {
              item.items = _.map(item.items, function(childItem) {
                if (childItem.name === itemName) {
                  childItem.value = value;
                  if (childItem.type === 'file') {
                    childItem.data = data;
                  }
                }
                return childItem;
              });
            }
          }
          return item;
        });
      }
      return group;
    });

    this.setState({groups: groups});

    // TODO: maybe this should only be on submit
    this.triggerChange(groups);
  },

  triggerChange: function(groups) {
    if (this.props.handleChange) {
      this.props.handleChange(this.getData(groups));
    }
  },

  getData: function(groups) {
    if (!groups) {
      groups = this.state.groups;
    }

    var getItemData = function(item) {
      var data = {
        'name': item.name,
        'value': item.value
      };
      if (item.type === 'file') {
        data.data = item.data;
      }
      return data;
    };

    var data = [];
    _.each(groups, function(group) {
      _.each(group.items, function(item) {
        if (item.type !== 'select_many') {
          data.push(getItemData(item));
        }
        if (item.type !== 'select_one') {
          _.each(item.items, function(childItem) {
            data.push(getItemData(childItem));
          });
        }
      });
    });

    return data;
  },

  render: function() {
    return (
      <ConfigGroups
        groups={this.state.groups}
        handleChange={this.handleGroupsChange}
        testUrl={this.props.testUrl} />
    );
  }
});

module.exports = Configure;
